@@ -5,6 +5,9 @@
 #' @param count the number of line you want to randomly extract and paste. 
 #' @param collapse if FALSE, the output will be a tibble. Default is TRUE, a character vector. 
 #' 
+#' @importFrom attempt stop_if_not
+#' @importFrom tokenizers tokenize_sentences
+#' 
 #' @return a character vector
 #' @export
 #'
@@ -12,11 +15,9 @@
 #' proust_random(4)
 
 proust_random <- function(count = 1, collapse = TRUE){
-  assertthat::assert_that(inherits(count, "numeric"), msg = "count should be a number")
-  assertthat::assert_that(inherits(collapse, "logical"), msg = "collapse should be a logical")
-  temp <- lapply(proust_books()$text, tokenizers::tokenize_sentences) %>%
-    unlist() %>%
-    sample(count)
+  stop_if_not(inherits(count, "numeric"), msg = "count should be a number")
+  stop_if_not(inherits(collapse, "logical"), msg = "collapse should be a logical")
+  temp <- sample(unlist(lapply(proust_books()$text, tokenize_sentences)), count) 
   if(collapse){
     return(paste(temp, sep = " ", collapse = " "))
   } else {
