@@ -1,7 +1,3 @@
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
 length_list <- function(vec){
   if(length(vec) == 0){
     return(NA)
